@@ -6,6 +6,7 @@ from . import (
     get,
     illustrators,
     io,
+    iterate,
     iterpitches,
     lyconst,
     lyenv,
@@ -15,7 +16,7 @@ from . import (
     wf,
 )
 from ._version import __version__, __version_info__
-from .attach import Wrapper, annotate, attach, detach
+from .bind import Wrapper, annotate, attach, detach
 from .bundle import LilyPondFormatBundle, SlotContributions
 from .configuration import (
     Configuration,
@@ -36,6 +37,7 @@ from .contextmanagers import (
 )
 from .cyclictuple import CyclicTuple
 from .duration import Duration, Multiplier, NonreducedFraction, Offset
+from .dynamic import Dynamic
 from .enums import (
     Center,
     Comparison,
@@ -61,57 +63,53 @@ from .exceptions import (
     UnboundedTimeIntervalError,
     WellformednessError,
 )
-from .expression import Expression, Signature
-from .format import LilyPondFormatManager
+from .format import FormatSpecification, storage
 from .get import Descendants, Lineage
 from .illustrators import illustrate
-from .indicators.Arpeggio import Arpeggio
-from .indicators.Articulation import Articulation
-from .indicators.BarLine import BarLine
-from .indicators.BeamCount import BeamCount
-from .indicators.BendAfter import BendAfter
-from .indicators.BowContactPoint import BowContactPoint
-from .indicators.BowMotionTechnique import BowMotionTechnique
-from .indicators.BowPressure import BowPressure
-from .indicators.BreathMark import BreathMark
-from .indicators.Clef import Clef, StaffPosition
-from .indicators.ColorFingering import ColorFingering
-from .indicators.Dynamic import Dynamic
-from .indicators.Fermata import Fermata
-from .indicators.Glissando import Glissando
-from .indicators.KeyCluster import KeyCluster
-from .indicators.KeySignature import KeySignature
-from .indicators.LaissezVibrer import LaissezVibrer
-from .indicators.LilyPondComment import LilyPondComment
-from .indicators.MarginMarkup import MarginMarkup
-from .indicators.MetronomeMark import MetronomeMark
-from .indicators.Mode import Mode
-from .indicators.Ottava import Ottava
-from .indicators.RehearsalMark import RehearsalMark
-from .indicators.Repeat import Repeat
-from .indicators.RepeatTie import RepeatTie
-from .indicators.StaffChange import StaffChange
-from .indicators.StartBeam import StartBeam
-from .indicators.StartGroup import StartGroup
-from .indicators.StartHairpin import StartHairpin
-from .indicators.StartMarkup import StartMarkup
-from .indicators.StartPhrasingSlur import StartPhrasingSlur
-from .indicators.StartPianoPedal import StartPianoPedal
-from .indicators.StartSlur import StartSlur
-from .indicators.StartTextSpan import StartTextSpan
-from .indicators.StartTrillSpan import StartTrillSpan
-from .indicators.StemTremolo import StemTremolo
-from .indicators.StopBeam import StopBeam
-from .indicators.StopGroup import StopGroup
-from .indicators.StopHairpin import StopHairpin
-from .indicators.StopPhrasingSlur import StopPhrasingSlur
-from .indicators.StopPianoPedal import StopPianoPedal
-from .indicators.StopSlur import StopSlur
-from .indicators.StopTextSpan import StopTextSpan
-from .indicators.StopTrillSpan import StopTrillSpan
-from .indicators.StringContactPoint import StringContactPoint
-from .indicators.Tie import Tie
-from .indicators.TimeSignature import TimeSignature
+from .indicators import (
+    Arpeggio,
+    Articulation,
+    BarLine,
+    BeamCount,
+    BendAfter,
+    BreathMark,
+    Clef,
+    ColorFingering,
+    Fermata,
+    Glissando,
+    KeyCluster,
+    KeySignature,
+    LaissezVibrer,
+    MarginMarkup,
+    MetronomeMark,
+    Mode,
+    Ottava,
+    RehearsalMark,
+    Repeat,
+    RepeatTie,
+    StaffChange,
+    StaffPosition,
+    StartBeam,
+    StartGroup,
+    StartHairpin,
+    StartMarkup,
+    StartPhrasingSlur,
+    StartPianoPedal,
+    StartSlur,
+    StartTextSpan,
+    StartTrillSpan,
+    StemTremolo,
+    StopBeam,
+    StopGroup,
+    StopHairpin,
+    StopPhrasingSlur,
+    StopPianoPedal,
+    StopSlur,
+    StopTextSpan,
+    StopTrillSpan,
+    Tie,
+    TimeSignature,
+)
 from .instruments import (
     Accordion,
     AltoFlute,
@@ -165,19 +163,9 @@ from .instruments import (
     Xylophone,
 )
 from .io import graph, play, show
-from .iterate import Iteration, iterate
-from .label import ColorMap, Label, label
-from .lilypond import lilypond
-from .lilypondfile import (
-    Block,
-    ContextBlock,
-    DateTimeToken,
-    LilyPondDimension,
-    LilyPondFile,
-    LilyPondLanguageToken,
-    LilyPondVersionToken,
-    PackageGitCommitToken,
-)
+from .label import ColorMap
+from .lilypondfile import Block, LilyPondFile
+from .lilypondformat import lilypond
 from .lyproxy import (
     LilyPondContext,
     LilyPondEngraver,
@@ -185,13 +173,12 @@ from .lyproxy import (
     LilyPondGrobInterface,
 )
 from .makers import LeafMaker, NoteMaker
-from .markups import Markup, Postscript, PostscriptOperator
+from .markups import Markup
 from .math import Infinity, NegativeInfinity
-from .meter import Meter, MeterList, MetricAccentKernel, OffsetCounter
+from .meter import Meter, MeterList, MetricAccentKernel
 from .metricmodulation import MetricModulation
 from .new import new
 from .obgc import OnBeatGraceContainer, on_beat_grace_container
-from .ordereddict import OrderedDict
 from .overrides import (
     IndexedTweakManager,
     IndexedTweakManagers,
@@ -211,51 +198,48 @@ from .parsers import parser
 from .parsers.base import Parser
 from .parsers.parse import parse
 from .pattern import Pattern, PatternTuple
-from .pitch.Accidental import Accidental
-from .pitch.Octave import Octave
-from .pitch.PitchRange import PitchRange
-from .pitch.SetClass import SetClass
-from .pitch.intervalclasses import (
-    IntervalClass,
-    NamedIntervalClass,
-    NamedInversionEquivalentIntervalClass,
-    NumberedIntervalClass,
-    NumberedInversionEquivalentIntervalClass,
-)
-from .pitch.intervals import Interval, NamedInterval, NumberedInterval
-from .pitch.operators import (
+from .pitch import (
+    Accidental,
     CompoundOperator,
     Duplication,
+    Interval,
+    IntervalClass,
+    IntervalClassSegment,
+    IntervalClassSet,
+    IntervalClassVector,
+    IntervalSegment,
+    IntervalSet,
+    IntervalVector,
     Inversion,
     Multiplication,
+    NamedInterval,
+    NamedIntervalClass,
+    NamedInversionEquivalentIntervalClass,
+    NamedPitch,
+    NamedPitchClass,
+    NumberedInterval,
+    NumberedIntervalClass,
+    NumberedInversionEquivalentIntervalClass,
+    NumberedPitch,
+    NumberedPitchClass,
+    Octave,
+    Pitch,
+    PitchClass,
+    PitchClassSegment,
+    PitchClassSet,
+    PitchClassVector,
+    PitchRange,
+    PitchSegment,
+    PitchSet,
+    PitchTyping,
+    PitchVector,
     Retrograde,
     Rotation,
-    Transposition,
-)
-from .pitch.pitchclasses import NamedPitchClass, NumberedPitchClass, PitchClass
-from .pitch.pitches import NamedPitch, NumberedPitch, Pitch, PitchTyping
-from .pitch.segments import (
-    IntervalClassSegment,
-    IntervalSegment,
-    PitchClassSegment,
-    PitchSegment,
     Segment,
-    TwelveToneRow,
-    pitch_class_segment,
-)
-from .pitch.sets import (
-    IntervalClassSet,
-    IntervalSet,
-    PitchClassSet,
-    PitchSet,
     Set,
-    pitch_set,
-)
-from .pitch.vectors import (
-    IntervalClassVector,
-    IntervalVector,
-    PitchClassVector,
-    PitchVector,
+    SetClass,
+    Transposition,
+    TwelveToneRow,
     Vector,
 )
 from .ratio import NonreducedRatio, Ratio
@@ -283,7 +267,7 @@ from .score import (
     Voice,
 )
 from .segmentmaker import SegmentMaker
-from .select import (
+from .selection import (
     DurationInequality,
     Inequality,
     LengthInequality,
@@ -292,10 +276,9 @@ from .select import (
     Selection,
     select,
 )
-from .sequence import Sequence, sequence
+from .sequence import Sequence
 from .spanners import (
     beam,
-    bow_contact_spanner,
     glissando,
     hairpin,
     horizontal_bracket,
@@ -307,12 +290,6 @@ from .spanners import (
     tie,
     trill_spanner,
 )
-from .storage import (
-    FormatSpecification,
-    StorageFormatManager,
-    StorageFormatSpecification,
-    storage,
-)
 from .string import String
 from .tag import Line, Tag, activate, deactivate
 from .templates import (
@@ -321,9 +298,8 @@ from .templates import (
     ScoreTemplate,
     StringOrchestraScoreTemplate,
     StringQuartetScoreTemplate,
-    TwoStaffPianoScoreTemplate,
 )
-from .timespan import AnnotatedTimespan, Timespan, TimespanList, timespan
+from .timespan import OffsetCounter, Timespan, TimespanList
 from .typedcollections import (
     TypedCollection,
     TypedCounter,
@@ -365,7 +341,6 @@ __all__ = [
     "AltoSaxophone",
     "AltoTrombone",
     "AltoVoice",
-    "AnnotatedTimespan",
     "Arpeggio",
     "Articulation",
     "AssignabilityError",
@@ -382,9 +357,6 @@ __all__ = [
     "BeforeGraceContainer",
     "BendAfter",
     "Block",
-    "BowContactPoint",
-    "BowMotionTechnique",
-    "BowPressure",
     "BreathMark",
     "Cello",
     "Center",
@@ -402,7 +374,6 @@ __all__ = [
     "Configuration",
     "Container",
     "Context",
-    "ContextBlock",
     "ContextManager",
     "Contrabass",
     "ContrabassClarinet",
@@ -410,7 +381,6 @@ __all__ = [
     "ContrabassSaxophone",
     "Contrabassoon",
     "CyclicTuple",
-    "DateTimeToken",
     "Descendants",
     "Down",
     "DrumNoteHead",
@@ -456,31 +426,24 @@ __all__ = [
     "IntervalSet",
     "IntervalVector",
     "Inversion",
-    "Iteration",
     "KeyCluster",
     "KeySignature",
-    "Label",
     "LaissezVibrer",
     "Leaf",
     "LeafMaker",
     "Left",
     "LengthInequality",
     "Less",
-    "LilyPondComment",
     "LilyPondContext",
-    "LilyPondDimension",
     "LilyPondEngraver",
     "LilyPondFile",
     "LilyPondFormatBundle",
-    "LilyPondFormatManager",
     "LilyPondGrob",
     "LilyPondGrobInterface",
-    "LilyPondLanguageToken",
     "LilyPondLiteral",
     "LilyPondOverride",
     "LilyPondParserError",
     "LilyPondSetting",
-    "LilyPondVersionToken",
     "Line",
     "Lineage",
     "LogicalTie",
@@ -525,10 +488,8 @@ __all__ = [
     "Offset",
     "OffsetCounter",
     "OnBeatGraceContainer",
-    "OrderedDict",
     "Ottava",
     "OverrideInterface",
-    "PackageGitCommitToken",
     "Parentage",
     "ParentageError",
     "Parser",
@@ -550,8 +511,6 @@ __all__ = [
     "PitchSet",
     "PitchTyping",
     "PitchVector",
-    "Postscript",
-    "PostscriptOperator",
     "ProgressIndicator",
     "Prototype",
     "Ratio",
@@ -575,7 +534,6 @@ __all__ = [
     "Set",
     "SetClass",
     "SettingInterface",
-    "Signature",
     "Skip",
     "SlotContributions",
     "SopraninoSaxophone",
@@ -603,10 +561,7 @@ __all__ = [
     "StopSlur",
     "StopTextSpan",
     "StopTrillSpan",
-    "StorageFormatManager",
-    "StorageFormatSpecification",
     "String",
-    "StringContactPoint",
     "StringNumber",
     "StringOrchestraScoreTemplate",
     "StringQuartetScoreTemplate",
@@ -630,7 +585,6 @@ __all__ = [
     "Tuplet",
     "TweakInterface",
     "TwelveToneRow",
-    "TwoStaffPianoScoreTemplate",
     "TypedCollection",
     "TypedCounter",
     "TypedFrozenset",
@@ -654,11 +608,11 @@ __all__ = [
     "annotate",
     "attach",
     "beam",
-    "bow_contact_spanner",
     "deactivate",
     "deprecated",
     "detach",
     "enumerate",
+    "format",
     "glissando",
     "graph",
     "hairpin",
@@ -677,9 +631,9 @@ __all__ = [
     "iterate_vertical_moments",
     "iterpitches",
     "label",
-    "lilypond",
     "list_all_classes",
     "list_all_functions",
+    "lilypond",
     "lyconst",
     "lyenv",
     "makers",
@@ -693,18 +647,14 @@ __all__ = [
     "persist",
     "phrasing_slur",
     "piano_pedal",
-    "pitch_class_segment",
-    "pitch_set",
     "play",
     "select",
-    "sequence",
     "setting",
     "show",
     "slur",
     "storage",
     "text_spanner",
     "tie",
-    "timespan",
     "trill_spanner",
     "tweak",
     "wf",
