@@ -9,10 +9,11 @@ import sys
 import tempfile
 import time
 
-from . import storage, string
-from .configuration import Configuration
+from . import configuration as _configuration
+from . import format as _format
+from . import string as _string
 
-configuration = Configuration()
+configuration = _configuration.Configuration()
 
 
 class ContextManager:
@@ -52,7 +53,7 @@ class ContextManager:
         """
         Gets interpreter representation.
         """
-        return storage.StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
 
 class FilesystemState(ContextManager):
@@ -184,7 +185,8 @@ class ForbidUpdate(ContextManager):
 
             >>> string = abjad.lilypond(staff)
             >>> print(string)
-            \new Staff {
+            \new Staff
+            {
                 <c' e'>8
                 <d' fs'>8
                 <d' fs'>2
@@ -448,6 +450,7 @@ class RedirectedStreams(ContextManager):
         >>> string_io.close()
         >>> print(result)
         hello, world!
+        <BLANKLINE>
 
     Redirected streams context manager is immutable.
     """
@@ -509,12 +512,10 @@ class RedirectedStreams(ContextManager):
     ### PRIVATE METHODS ###
 
     def _get_format_specification(self):
-        return storage.FormatSpecification(
-            self,
+        return _format.FormatSpecification(
             repr_is_bracketed=True,
-            repr_is_indented=False,
             storage_format_is_bracketed=True,
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
             storage_format_args_values=[],
             storage_format_keyword_names=[],
         )
@@ -855,7 +856,7 @@ class Timer(ContextManager):
 
         Returns string.
         """
-        identifier = string.String("second").pluralize(int(self.elapsed_time))
+        identifier = _string.String("second").pluralize(int(self.elapsed_time))
         message = f"total time {int(self.elapsed_time)} {identifier} ..."
         return message
 
