@@ -4,9 +4,9 @@ import typing
 
 import quicktions
 
-from . import exceptions
+from . import exceptions as _exceptions
+from . import format as _format
 from . import math as _math
-from . import storage
 
 
 class Duration(quicktions.Fraction):
@@ -255,8 +255,6 @@ class Duration(quicktions.Fraction):
     def __hash__(self) -> int:
         """
         Hashes duration.
-
-        Required to be explicitly redefined on Python 3 if __eq__ changes.
         """
         return super().__hash__()
 
@@ -400,7 +398,7 @@ class Duration(quicktions.Fraction):
         """
         Gets interpreter representation.
         """
-        return storage.StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     def __rmod__(self, *arguments):
         """
@@ -468,10 +466,9 @@ class Duration(quicktions.Fraction):
     ### PRIVATE METHODS ###
 
     def _get_format_specification(self):
-        return storage.FormatSpecification(
-            client=self,
+        return _format.FormatSpecification(
             storage_format_args_values=[self.numerator, self.denominator],
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
             storage_format_keyword_names=[],
         )
 
@@ -495,7 +492,7 @@ class Duration(quicktions.Fraction):
 
     @staticmethod
     def _initialize_from_lilypond_duration_string(duration_string):
-        numeric_body_strings = [str(2 ** n) for n in range(8)]
+        numeric_body_strings = [str(2**n) for n in range(8)]
         other_body_strings = [r"\\breve", r"\\longa", r"\\maxima"]
         body_strings = numeric_body_strings + other_body_strings
         body_strings = "|".join(body_strings)
@@ -519,7 +516,7 @@ class Duration(quicktions.Fraction):
         rational = body_duration
         for n in range(len(dots_string)):
             exponent = n + 1
-            denominator = 2 ** exponent
+            denominator = 2**exponent
             multiplier = quicktions.Fraction(1, denominator)
             addend = multiplier * body_duration
             rational += addend
@@ -582,7 +579,7 @@ class Duration(quicktions.Fraction):
         Raises assignability error when duration is not assignable.
         """
         if not self.is_assignable:
-            raise exceptions.AssignabilityError
+            raise _exceptions.AssignabilityError
         binary_string = _math.integer_to_binary_string(self.numerator)
         digit_sum = sum([int(x) for x in list(binary_string)])
         dot_count = digit_sum - 1
@@ -941,7 +938,7 @@ class Duration(quicktions.Fraction):
         Raises assignability error when duration is not assignable.
         """
         if not self.is_assignable:
-            raise exceptions.AssignabilityError(self)
+            raise _exceptions.AssignabilityError(self)
         undotted_rational = self.equal_or_lesser_power_of_two
         if undotted_rational <= 1:
             undotted_duration_string = str(undotted_rational.denominator)
@@ -1118,7 +1115,7 @@ class Duration(quicktions.Fraction):
             >>> clock_string
             "1'57''"
 
-            >>> string = f'"{clock_string}"'
+            >>> string = rf"\markup {{ {clock_string} }}"
             >>> markup = abjad.Markup(string, direction=abjad.Up)
             >>> abjad.attach(markup, note)
             >>> abjad.show(note) # doctest: +SKIP
@@ -1294,7 +1291,7 @@ class Multiplier(Duration):
         """
         assert isinstance(dot_count, int), repr(dot_count)
         assert 0 <= dot_count, repr(dot_count)
-        denominator = 2 ** dot_count
+        denominator = 2**dot_count
         numerator = 2 ** (dot_count + 1) - 1
         return Multiplier(numerator, denominator)
 
@@ -1692,8 +1689,6 @@ class Offset(Duration):
     def __hash__(self) -> int:
         """
         Hashes offset.
-
-        Redefined in tandem with __eq__.
         """
         return super().__hash__()
 
@@ -1893,10 +1888,9 @@ class Offset(Duration):
         values = [(self.numerator, self.denominator)]
         if self._get_displacement():
             names = ["displacement"]
-        return storage.FormatSpecification(
-            client=self,
+        return _format.FormatSpecification(
             storage_format_args_values=values,
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
             storage_format_keyword_names=names,
         )
 
@@ -2214,8 +2208,6 @@ class NonreducedFraction(quicktions.Fraction):
     def __hash__(self) -> int:
         """
         Hashes nonreduced fraction.
-
-        Required to be explicitly redefined on Python 3 if __eq__ changes.
         """
         return super().__hash__()
 
@@ -2330,7 +2322,7 @@ class NonreducedFraction(quicktions.Fraction):
             NonreducedFraction(3, 6)
 
         """
-        return storage.StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     def __rmul__(self, argument) -> "NonreducedFraction":
         """
@@ -2409,11 +2401,9 @@ class NonreducedFraction(quicktions.Fraction):
         return result
 
     def _get_format_specification(self):
-        return storage.FormatSpecification(
-            client=self,
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             storage_format_args_values=[self.numerator, self.denominator],
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
             storage_format_keyword_names=[],
         )
 
