@@ -4,14 +4,11 @@ Instrument classes.
 import copy
 import typing
 
-from . import enumerate
-from .markups import Markup
-from .pitch.PitchRange import PitchRange
-from .pitch.pitchclasses import NamedPitchClass
-from .pitch.pitches import NamedPitch
-from .pitch.segments import PitchSegment
-from .storage import FormatSpecification, StorageFormatManager
-from .string import String
+from . import enumerate as _enumerate
+from . import format as _format
+from . import markups as _markups
+from . import pitch as _pitch
+from . import string as _string
 
 
 class Instrument:
@@ -25,14 +22,14 @@ class Instrument:
         >>> voice_1 = abjad.Voice("e'8 g'8 f'8 a'8")
         >>> flute = abjad.Flute()
         >>> abjad.attach(flute, voice_1[0], context='Voice')
-        >>> flute_markup = abjad.Markup('(flute)', direction=abjad.Up)
+        >>> flute_markup = abjad.Markup(r'\markup (flute)', direction=abjad.Up)
         >>> abjad.attach(flute_markup, voice_1[0])
         >>> abjad.attach(abjad.LilyPondLiteral(r'\voiceOne'), voice_1)
         >>> voice_2 = abjad.Voice("c'2")
         >>> abjad.attach(abjad.LilyPondLiteral(r'\voiceTwo'), voice_2)
         >>> viola = abjad.Viola()
         >>> abjad.attach(viola, voice_2[0], context='Voice')
-        >>> viola_markup = abjad.Markup('(viola)', direction=abjad.Down)
+        >>> viola_markup = abjad.Markup(r'\markup (viola)', direction=abjad.Down)
         >>> abjad.attach(viola_markup, voice_2[0])
         >>> staff = abjad.Staff([voice_1, voice_2], simultaneous=True)
         >>> abjad.show(staff) # doctest: +SKIP
@@ -47,7 +44,7 @@ class Instrument:
                 {
                     \voiceOne
                     e'8
-                    ^ \markup { (flute) }
+                    ^ \markup (flute)
                     g'8
                     f'8
                     a'8
@@ -56,7 +53,7 @@ class Instrument:
                 {
                     \voiceTwo
                     c'2
-                    _ \markup { (viola) }
+                    _ \markup (viola)
                 }
             >>
 
@@ -120,27 +117,27 @@ class Instrument:
             name = str(name)
         self._name = name
         if markup is not None:
-            markup = Markup(markup)
+            markup = _markups.Markup(str(markup))
         self._name_markup = markup
         if short_name is not None:
             short_name = str(short_name)
         self._short_name = short_name
         if short_markup is not None:
-            short_markup = Markup(short_markup)
+            short_markup = _markups.Markup(str(short_markup))
         self._short_name_markup = short_markup
         allowable_clefs = allowable_clefs or ("treble",)
         self._allowable_clefs = allowable_clefs
         if isinstance(pitch_range, str):
-            pitch_range = PitchRange(pitch_range)
-        elif isinstance(pitch_range, PitchRange):
+            pitch_range = _pitch.PitchRange(pitch_range)
+        elif isinstance(pitch_range, _pitch.PitchRange):
             pitch_range = copy.copy(pitch_range)
         elif pitch_range is None:
-            pitch_range = PitchRange()
+            pitch_range = _pitch.PitchRange()
         else:
             raise TypeError(pitch_range)
         self._pitch_range = pitch_range
-        middle_c_sounding_pitch = middle_c_sounding_pitch or NamedPitch("c'")
-        middle_c_sounding_pitch = NamedPitch(middle_c_sounding_pitch)
+        middle_c_sounding_pitch = middle_c_sounding_pitch or _pitch.NamedPitch("c'")
+        middle_c_sounding_pitch = _pitch.NamedPitch(middle_c_sounding_pitch)
         self._middle_c_sounding_pitch = middle_c_sounding_pitch
         if primary is not None:
             primary = bool(primary)
@@ -152,27 +149,33 @@ class Instrument:
 
     def __eq__(self, argument) -> bool:
         """
-        Is true when all initialization values of Abjad value object equal
-        the initialization values of ``argument``.
+        Compares all nine initializer parameters.
         """
-        return StorageFormatManager.compare_objects(self, argument)
+        if isinstance(argument, type(self)):
+            return (
+                self.allowable_clefs == argument.allowable_clefs
+                and self.context == argument.context
+                and self.markup == argument.markup
+                and self.middle_c_sounding_pitch == argument.middle_c_sounding_pitch
+                and self.name == argument.name
+                and self.pitch_range == argument.pitch_range
+                and self.primary == argument.primary
+                and self.short_name == argument.short_name
+                and self.short_markup == argument.short_markup
+            )
+        return False
 
     def __hash__(self) -> int:
         """
-        Hashes Abjad value object.
+        Hashes instrument.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __repr__(self) -> str:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE PROPERTIES ###
 
@@ -196,10 +199,7 @@ class Instrument:
 
     def _get_format_specification(self):
         keywords = []
-        return FormatSpecification(
-            self,
-            repr_args_values=[],
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             repr_keyword_names=keywords,
         )
 
@@ -210,17 +210,16 @@ class Instrument:
         if self._name_markup is None:
             if self.name:
                 string = self.name
-                string = String(string).capitalize_start()
-                markup = Markup(contents=string)
+                string = _string.String(string).capitalize_start()
+                markup = _markups.Markup(rf"\markup {string}")
                 self._name_markup = markup
             else:
                 self._name_markup = None
         if self._short_name_markup is None:
             if self.short_name:
                 string = self.short_name
-                string = String(string).capitalize_start()
-                markup = Markup(contents=string)
-                self._short_name_markup = markup
+                string = _string.String(string).capitalize_start()
+                markup = _markups.Markup(rf"\markup {string}")
             else:
                 self._short_name_markup = None
 
@@ -270,10 +269,13 @@ class Instrument:
         """
         if self._name_markup is None:
             self._initialize_default_name_markups()
-        if not isinstance(self._name_markup, Markup):
-            markup = Markup(contents=self._name_markup)
+        if self._name_markup is None:
+            return
+        if not isinstance(self._name_markup, _markups.Markup):
+            assert isinstance(self._name_markup, str), repr(self._name_markup)
+            markup = _markups.Markup(rf"\markup {self._name_markup}")
             self._name_markup = markup
-        if self._name_markup.contents != ("",):
+        if self._name_markup.string:
             return self._name_markup
 
     @property
@@ -340,10 +342,15 @@ class Instrument:
         """
         if self._short_name_markup is None:
             self._initialize_default_name_markups()
-        if not isinstance(self._short_name_markup, Markup):
-            markup = Markup(contents=self._short_name_markup)
+        if self._short_name_markup is None:
+            return
+        if not isinstance(self._short_name_markup, _markups.Markup):
+            assert isinstance(self._short_name_markup, str), repr(
+                self._short_name_markup
+            )
+            markup = _markups.Markup(rf"\markup {self._short_name_markup}")
             self._short_name_markup = markup
-        if self._short_name_markup.contents != ("",):
+        if self._short_name_markup.string:
             return self._short_name_markup
 
     @property
@@ -406,21 +413,17 @@ class StringNumber:
 
     def __eq__(self, argument) -> bool:
         """
-        Is true when all initialization values of Abjad value object equal
-        the initialization values of ``argument``.
+        Compares ``numbers``.
         """
-        return StorageFormatManager.compare_objects(self, argument)
+        if isinstance(argument, type(self)):
+            return self.numbers == argument.numbers
+        return False
 
     def __hash__(self) -> int:
         """
-        Hashes Abjad value object.
+        Hashes string number.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     ### PUBLIC PROPERTIES ###
 
@@ -516,44 +519,40 @@ class Tuning:
         if pitches is not None:
             if isinstance(pitches, type(self)):
                 pitches = pitches.pitches
-            pitches = PitchSegment(items=pitches, item_class=NamedPitch)
-        self._pitches: typing.Optional[PitchSegment] = pitches
+            pitches = _pitch.PitchSegment(items=pitches, item_class=_pitch.NamedPitch)
+        self._pitches: typing.Optional[_pitch.PitchSegment] = pitches
 
     ### SPECIAL METHODS ###
 
     def __eq__(self, argument) -> bool:
         """
-        Is true when all initialization values of Abjad value object equal
-        the initialization values of ``argument``.
+        Compares ``pitches``.
         """
-        return StorageFormatManager.compare_objects(self, argument)
+        if isinstance(argument, type(self)):
+            return self.pitches == argument.pitches
+        return False
 
     def __hash__(self) -> int:
         """
-        Hashes Abjad value object.
+        Hashes tuning.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __repr__(self) -> str:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE METHODS ###
 
     def _get_format_specification(self):
-        return FormatSpecification(client=self)
+        return _format.FormatSpecification()
 
     ### PUBLIC PROPERTIES ###
 
     @property
-    def pitch_ranges(self) -> typing.List[PitchRange]:
+    def pitch_ranges(self) -> typing.List[_pitch.PitchRange]:
         """
         Gets two-octave pitch-ranges for each pitch in this tuning.
 
@@ -570,12 +569,12 @@ class Tuning:
         """
         result = []
         for pitch in self.pitches or []:
-            pitch_range = PitchRange.from_pitches(pitch, pitch + 24)
+            pitch_range = _pitch.PitchRange.from_pitches(pitch, pitch + 24)
             result.append(pitch_range)
         return result
 
     @property
-    def pitches(self) -> typing.Optional[PitchSegment]:
+    def pitches(self) -> typing.Optional[_pitch.PitchSegment]:
         """
         Gets pitches of tuning.
 
@@ -609,7 +608,7 @@ class Tuning:
 
     def get_pitch_ranges_by_string_number(
         self, string_number: StringNumber
-    ) -> typing.Tuple[PitchRange, ...]:
+    ) -> typing.Tuple[_pitch.PitchRange, ...]:
         """
         Gets tuning pitch ranges by string number.
 
@@ -636,7 +635,7 @@ class Tuning:
 
     def get_pitches_by_string_number(
         self, string_number: StringNumber
-    ) -> typing.Tuple[NamedPitch, ...]:
+    ) -> typing.Tuple[_pitch.NamedPitch, ...]:
         """
         Gets tuning pitches by string number.
 
@@ -740,16 +739,18 @@ class Tuning:
 
         """
         assert self.pitches is not None
-        pitch_classes = [NamedPitchClass(_) for _ in pitch_classes]
+        pitch_classes = [_pitch.NamedPitchClass(_) for _ in pitch_classes]
         pitch_classes.extend([None] * (len(self.pitches) - len(pitch_classes)))
-        permutations = enumerate.yield_permutations(pitch_classes)
+        permutations = _enumerate.yield_permutations(pitch_classes)
         permutations = set([tuple(_) for _ in permutations])
         pitch_ranges = self.pitch_ranges
-        result: typing.List[typing.Tuple[typing.Union[NamedPitch, None], ...]] = []
+        result: typing.List[
+            typing.Tuple[typing.Union[_pitch.NamedPitch, None], ...]
+        ] = []
         for permutation in permutations:
             sequences: typing.List = []
             for pitch_range, pitch_class in zip(pitch_ranges, permutation):
-                pitches: typing.List[typing.Optional[NamedPitch]]
+                pitches: typing.List[typing.Optional[_pitch.NamedPitch]]
                 if pitch_class is None:
                     sequences.append([None])
                     continue
@@ -761,7 +762,7 @@ class Tuning:
                 if not pitches:
                     pitches = [None]
                 sequences.append(pitches)
-            subresult = enumerate.yield_outer_product(sequences)
+            subresult = _enumerate.outer_product(sequences)
             subresult = [tuple(x) for x in subresult]
             result.extend(subresult)
         result.sort()
