@@ -1,12 +1,16 @@
 import typing
 
-from . import _inspect, enums, illustrators, score, typings
-from .bundle import LilyPondFormatBundle
-from .markups import Markup
-from .new import new
-from .ratio import Ratio
-from .select import Selection
-from .storage import StorageFormatManager
+from . import _inspect
+from . import bundle as _bundle
+from . import enums as _enums
+from . import format as _format
+from . import illustrators as _illustrators
+from . import markups as _markups
+from . import new as _new
+from . import ratio as _ratio
+from . import score as _score
+from . import selection as _selection
+from . import typings as _typings
 
 
 class MetricModulation:
@@ -23,11 +27,15 @@ class MetricModulation:
         ...     right_rhythm=abjad.Note("c'4."),
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup \abjad-metric-modulation #3 #1 #2 #1 #'(1 . 1)
 
     ..  container:: example
@@ -39,11 +47,15 @@ class MetricModulation:
         ...     right_rhythm=abjad.Note("c'4"),
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup \abjad-metric-modulation-tuplet-lhs #2 #0 #4 #5 #2 #0 #'(1 . 1)
 
         >>> metric_modulation = abjad.MetricModulation(
@@ -51,11 +63,15 @@ class MetricModulation:
         ...     right_rhythm=abjad.Tuplet((4, 5), "c'4"),
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup \abjad-metric-modulation-tuplet-rhs #2 #0 #2 #0 #4 #5 #'(1 . 1)
 
     ..  container:: example
@@ -67,11 +83,15 @@ class MetricModulation:
         ...     right_rhythm=abjad.Tuplet((2, 3), "c8"),
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup \abjad-metric-modulation-tuplet-rhs #4 #1 #3 #0 #2 #3 #'(1 . 1)
 
     ..  container:: example
@@ -85,21 +105,25 @@ class MetricModulation:
         ...     right_rhythm=notes,
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup { \score
                 {
-                    \new Score
+                    \context Score = "Score"
                     \with
                     {
                         \override SpacingSpanner.spacing-increment = 0.5
                         proportionalNotationDuration = ##f
                     }
                     <<
-                        \new RhythmicStaff
+                        \context RhythmicStaff = "Rhythmic_Staff"
                         \with
                         {
                             \remove Time_signature_engraver
@@ -120,7 +144,8 @@ class MetricModulation:
                             c'4
                         }
                     >>
-                    \layout {
+                    \layout
+                    {
                         indent = 0
                         ragged-right = ##t
                     }
@@ -129,14 +154,14 @@ class MetricModulation:
             \hspace #-0.5
             \score
                 {
-                    \new Score
+                    \context Score = "Score"
                     \with
                     {
                         \override SpacingSpanner.spacing-increment = 0.5
                         proportionalNotationDuration = ##f
                     }
                     <<
-                        \new RhythmicStaff
+                        \context RhythmicStaff = "Rhythmic_Staff"
                         \with
                         {
                             \remove Time_signature_engraver
@@ -159,7 +184,8 @@ class MetricModulation:
                             c'16
                         }
                     >>
-                    \layout {
+                    \layout
+                    {
                         indent = 0
                         ragged-right = ##t
                     }
@@ -177,21 +203,25 @@ class MetricModulation:
         ...     right_rhythm=tuplet,
         ...     )
 
-        >>> abjad.show(metric_modulation) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile(
+        ...     [r'\include "abjad.ily"', metric_modulation]
+        ... )
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
-            >>> print(abjad.lilypond(metric_modulation))
+            >>> string = abjad.lilypond(metric_modulation)
+            >>> print(string)
             \markup { \score
                 {
-                    \new Score
+                    \context Score = "Score"
                     \with
                     {
                         \override SpacingSpanner.spacing-increment = 0.5
                         proportionalNotationDuration = ##f
                     }
                     <<
-                        \new RhythmicStaff
+                        \context RhythmicStaff = "Rhythmic_Staff"
                         \with
                         {
                             \remove Time_signature_engraver
@@ -212,7 +242,8 @@ class MetricModulation:
                             c'4
                         }
                     >>
-                    \layout {
+                    \layout
+                    {
                         indent = 0
                         ragged-right = ##t
                     }
@@ -221,14 +252,14 @@ class MetricModulation:
             \hspace #-0.5
             \score
                 {
-                    \new Score
+                    \context Score = "Score"
                     \with
                     {
                         \override SpacingSpanner.spacing-increment = 0.5
                         proportionalNotationDuration = ##f
                     }
                     <<
-                        \new RhythmicStaff
+                        \context RhythmicStaff = "Rhythmic_Staff"
                         \with
                         {
                             \remove Time_signature_engraver
@@ -247,14 +278,16 @@ class MetricModulation:
                         }
                         {
                             \tweak edge-height #'(0.7 . 0)
-                            \times 2/3 {
+                            \times 2/3
+                            {
                                 c'4
                                 ~
                                 c'16
                             }
                         }
                     >>
-                    \layout {
+                    \layout
+                    {
                         indent = 0
                         ragged-right = ##t
                     }
@@ -276,7 +309,8 @@ class MetricModulation:
         >>> abjad.attach(metric_modulation, staff[3])
         >>> abjad.override(staff).TextScript.staff_padding = 2.5
 
-        >>> abjad.show(score) # doctest: +SKIP
+        >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', score])
+        >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         ..  docs::
 
@@ -322,9 +356,9 @@ class MetricModulation:
         right_rhythm,
         *,
         hide: bool = None,
-        left_markup: Markup = None,
-        right_markup: Markup = None,
-        scale: typing.Tuple[typings.Number, typings.Number] = (1, 1),
+        left_markup: _markups.Markup = None,
+        right_markup: _markups.Markup = None,
+        scale: typing.Tuple[_typings.Number, _typings.Number] = (1, 1),
     ) -> None:
         if hide is not None:
             hide = bool(hide)
@@ -335,10 +369,10 @@ class MetricModulation:
         self._right_rhythm = right_rhythm
         self._right_rhythm = right_rhythm
         if left_markup is not None:
-            assert isinstance(left_markup, Markup)
+            assert isinstance(left_markup, _markups.Markup)
         self._left_markup = left_markup
         if right_markup is not None:
-            assert isinstance(right_markup, Markup)
+            assert isinstance(right_markup, _markups.Markup)
         self._right_markup = right_markup
         assert isinstance(scale, tuple), repr(scale)
         self._scale = scale
@@ -405,21 +439,14 @@ class MetricModulation:
     def __hash__(self) -> int:
         """
         Hashes metric modulation.
-
-        Redefined in tandem with __eq__.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __repr__(self) -> str:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     def __str__(self) -> str:
         r"""
@@ -472,10 +499,10 @@ class MetricModulation:
         return str(self)
 
     def _get_lilypond_format_bundle(self, component=None):
-        bundle = LilyPondFormatBundle()
+        bundle = _bundle.LilyPondFormatBundle()
         if not self.hide:
             markup = self._get_markup()
-            markup = new(markup, direction=enums.Up)
+            markup = _new.new(markup, direction=_enums.Up)
             markup_format_pieces = markup._get_format_pieces()
             bundle.after.markup.extend(markup_format_pieces)
         return bundle
@@ -483,18 +510,18 @@ class MetricModulation:
     def _get_markup(self):
         string = self._get_lilypond_command_string()
         if string is not None:
-            markup = Markup(rf"\markup {string}", literal=True)
+            markup = _markups.Markup(rf"\markup {string}")
             return markup
         strings = []
-        string = illustrators.selection_to_score_markup_string(self.left_rhythm)
+        string = _illustrators.selection_to_score_markup_string(self.left_rhythm)
         strings.extend(string.split("\n"))
         strings.append("=")
         strings.append(r"\hspace #-0.5")
-        string = illustrators.selection_to_score_markup_string(self.right_rhythm)
+        string = _illustrators.selection_to_score_markup_string(self.right_rhythm)
         strings.extend(string.split("\n"))
         string = "\n".join(strings)
         string = rf"\markup {{ {string} }}"
-        markup = Markup(string, literal=True)
+        markup = _markups.Markup(string)
         return markup
 
     def _get_markup_arguments(self):
@@ -539,7 +566,7 @@ class MetricModulation:
 
     def _initialize_rhythm(self, rhythm):
         if not hasattr(rhythm, "_items"):
-            selection = Selection([rhythm])
+            selection = _selection.Selection([rhythm])
         else:
             assert hasattr(rhythm, "_items"), repr(rhythm)
             selection = rhythm
@@ -547,9 +574,9 @@ class MetricModulation:
 
     def _lhs_tuplet(self):
         if (
-            isinstance(self.left_rhythm[0], score.Tuplet)
+            isinstance(self.left_rhythm[0], _score.Tuplet)
             and len(self.left_rhythm[0]) == 1
-            and isinstance(self.right_rhythm[0], score.Note)
+            and isinstance(self.right_rhythm[0], _score.Note)
             and len(self.right_rhythm) == 1
         ):
             return True
@@ -557,9 +584,9 @@ class MetricModulation:
 
     def _note_to_note(self):
         if (
-            isinstance(self.left_rhythm[0], score.Note)
+            isinstance(self.left_rhythm[0], _score.Note)
             and len(self.left_rhythm) == 1
-            and isinstance(self.right_rhythm[0], score.Note)
+            and isinstance(self.right_rhythm[0], _score.Note)
             and len(self.right_rhythm) == 1
         ):
             return True
@@ -567,9 +594,9 @@ class MetricModulation:
 
     def _rhs_tuplet(self):
         if (
-            isinstance(self.left_rhythm[0], score.Note)
+            isinstance(self.left_rhythm[0], _score.Note)
             and len(self.left_rhythm) == 1
-            and isinstance(self.right_rhythm[0], score.Tuplet)
+            and isinstance(self.right_rhythm[0], _score.Tuplet)
             and len(self.right_rhythm[0]) == 1
         ):
             return True
@@ -585,7 +612,7 @@ class MetricModulation:
         return self._hide
 
     @property
-    def left_markup(self) -> typing.Optional[Markup]:
+    def left_markup(self) -> typing.Optional[_markups.Markup]:
         """
         Gets left markup of metric modulation.
 
@@ -619,7 +646,7 @@ class MetricModulation:
         return self._left_rhythm
 
     @property
-    def ratio(self) -> Ratio:
+    def ratio(self) -> _ratio.Ratio:
         """
         Gets ratio of metric modulation.
 
@@ -636,11 +663,11 @@ class MetricModulation:
         left_duration = _inspect._get_duration(self.left_rhythm)
         right_duration = _inspect._get_duration(self.right_rhythm)
         duration = left_duration / right_duration
-        ratio = Ratio(duration.pair)
+        ratio = _ratio.Ratio(duration.pair)
         return ratio
 
     @property
-    def right_markup(self) -> typing.Optional[Markup]:
+    def right_markup(self) -> typing.Optional[_markups.Markup]:
         r"""Gets right markup of metric modulation.
 
         ..  container:: example
@@ -672,7 +699,7 @@ class MetricModulation:
         return self._right_rhythm
 
     @property
-    def scale(self) -> typing.Tuple[typings.Number, typings.Number]:
+    def scale(self) -> typing.Tuple[_typings.Number, _typings.Number]:
         r"""
         Gets scale of output markup.
 
@@ -690,7 +717,8 @@ class MetricModulation:
             >>> abjad.attach(metric_modulation, staff[3])
             >>> abjad.override(staff).TextScript.staff_padding = 2.5
 
-            >>> abjad.show(score) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', score])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
