@@ -1,17 +1,17 @@
 import copy
 import typing
 
-from . import enums
+from . import bundle as _bundle
+from . import enums as _enums
+from . import format as _format
+from . import fsv as _fsv
+from . import lyenv as _lyenv
+from . import string as _string
 from . import tag as _tag
-from .bundle import LilyPondFormatBundle
-from .fsv import format_scheme_value
-from .lyenv import contexts, grob_interfaces
-from .storage import FormatSpecification, StorageFormatManager
-from .string import String
 
 
 def format_embedded_scheme_value(value):
-    result = format_scheme_value(value)
+    result = _fsv.format_scheme_value(value)
     if isinstance(value, bool):
         result = "#" + result
     return result
@@ -56,11 +56,11 @@ def format_lilypond_value(argument) -> str:
     if argument is False:
         return "##f"
     if argument in (
-        enums.Up,
-        enums.Down,
-        enums.Left,
-        enums.Right,
-        enums.Center,
+        _enums.Up,
+        _enums.Down,
+        _enums.Left,
+        _enums.Right,
+        _enums.Center,
     ):
         return rf"#{repr(argument).lower()}"
     if argument in lilypond_color_constants:
@@ -73,13 +73,13 @@ def format_lilypond_value(argument) -> str:
 def make_lilypond_override_string(
     grob, attribute, value, context=None, once=False
 ) -> str:
-    # camel_name = String(grob).to_upper_camel_case()
+    # camel_name = _string.String(grob).to_upper_camel_case()
     # assert grob == camel_name, repr((grob, camel_name))
-    grob = String(grob).to_upper_camel_case()
+    grob = _string.String(grob).to_upper_camel_case()
     attribute = format_lilypond_attribute(attribute)
     value = format_lilypond_value(value)
     if context is not None:
-        context = String(context).capitalize_start() + "."
+        context = _string.String(context).capitalize_start() + "."
     else:
         context = ""
     if once is True:
@@ -91,14 +91,14 @@ def make_lilypond_override_string(
 
 
 def make_lilypond_revert_string(grob, attribute, context=None) -> str:
-    # camel_name = String(grob).to_upper_camel_case()
+    # camel_name = _string.String(grob).to_upper_camel_case()
     # assert grob == camel_name, repr((grob, camel_name))
-    grob = String(grob).to_upper_camel_case()
+    grob = _string.String(grob).to_upper_camel_case()
     dotted = format_lilypond_attribute(attribute)
     if context is not None:
-        # camel_name = String(context).to_upper_camel_case()
+        # camel_name = _string.String(context).to_upper_camel_case()
         # assert context == camel_name, repr((context, camel_name))
-        context = String(context).to_upper_camel_case()
+        context = _string.String(context).to_upper_camel_case()
         context += "."
     else:
         context = ""
@@ -110,9 +110,9 @@ def make_lilypond_tweak_string(
     attribute, value, *, directed=True, grob=None, literal=None
 ) -> str:
     if grob is not None:
-        # camel_name = String(grob).to_upper_camel_case()
+        # camel_name = _string.String(grob).to_upper_camel_case()
         # assert grob == camel_name, repr((grob, camel_name))
-        grob = String(grob).to_upper_camel_case()
+        grob = _string.String(grob).to_upper_camel_case()
         grob += "."
     else:
         grob = ""
@@ -205,7 +205,8 @@ class LilyPondLiteral:
         >>> print(string)
         \new Staff
         {
-            \slurDotted %! +PARTS
+            %! +PARTS
+            \slurDotted
             c'8
             (
             d'8
@@ -236,9 +237,12 @@ class LilyPondLiteral:
             c'8
             (
             d'8
-            \stopStaff %! +PARTS
-            \startStaff %! +PARTS
-            \once \override Staff.StaffSymbol.color = #red %! +PARTS
+            %! +PARTS
+            \stopStaff
+            %! +PARTS
+            \startStaff
+            %! +PARTS
+            \once \override Staff.StaffSymbol.color = #red
             e'8
             f'8
             )
@@ -310,27 +314,24 @@ class LilyPondLiteral:
 
     def __eq__(self, argument) -> bool:
         """
-        Is true when all initialization values of Abjad value object equal
-        the initialization values of ``argument``.
+        Compares ``argument`` and ``format_slot``.
         """
-        return StorageFormatManager.compare_objects(self, argument)
+        if isinstance(argument, type(self)):
+            if self.argument == argument.argument:
+                return self.format_slot == argument.format_slot
+        return False
 
     def __hash__(self) -> int:
         """
-        Hashes Abjad value object.
+        Hashes LilyPond literal.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __repr__(self) -> str:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE METHODS ###
 
@@ -348,14 +349,13 @@ class LilyPondLiteral:
         return self.argument[:]
 
     def _get_format_specification(self):
-        return FormatSpecification(
-            client=self,
+        return _format.FormatSpecification(
             storage_format_args_values=[self.argument],
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
         )
 
     def _get_lilypond_format_bundle(self, component=None):
-        bundle = LilyPondFormatBundle()
+        bundle = _bundle.LilyPondFormatBundle()
         format_slot = bundle.get(self.format_slot)
         if self.tweaks:
             tweaks = self.tweaks._list_format_contributions(directed=self.directed)
@@ -598,8 +598,6 @@ class Interface:
     def __hash__(self) -> int:
         """
         Hashes LilyPond name manager.
-
-        Redefined in tandem with __eq__.
         """
         return super().__hash__()
 
@@ -641,17 +639,11 @@ class LilyPondOverride:
         ...        "left",
         ...        "text",
         ...        ),
-        ...    value=abjad.Markup(r"\bold { over pressure }"),
+        ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
         ...    )
 
         >>> print(override.override_string)
-        \once \override Staff.TextSpanner.bound-details.left.text = \markup {
-            \bold
-                {
-                    over
-                    pressure
-                }
-            }
+        \once \override Staff.TextSpanner.bound-details.left.text = \markup \bold { over pressure }
 
     """
 
@@ -712,15 +704,13 @@ class LilyPondOverride:
     def __hash__(self) -> int:
         """
         Hashes LilyPond grob override.
-
-        Redefined in tandem with __eq__.
         """
         return super().__hash__()
 
     ### PRIVATE METHODS ###
 
     def _get_lilypond_format_bundle(self, component=None):
-        bundle = LilyPondFormatBundle()
+        bundle = _bundle.LilyPondFormatBundle()
         if not self.once:
             revert_format = "\n".join(self.revert_format_pieces)
             bundle.grob_reverts.append(revert_format)
@@ -809,7 +799,7 @@ class LilyPondOverride:
             ...        "left",
             ...        "text",
             ...        ),
-            ...    value=abjad.Markup(r"\bold { over pressure }"),
+            ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
             ...    )
             >>> override.lilypond_type
             'Staff'
@@ -841,7 +831,7 @@ class LilyPondOverride:
             ...        "left",
             ...        "text",
             ...        ),
-            ...    value=abjad.Markup(r"\bold { over pressure }"),
+            ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
             ...    )
             >>> bool(override.once)
             True
@@ -873,18 +863,12 @@ class LilyPondOverride:
             ...        "left",
             ...        "text",
             ...        ),
-            ...    value=abjad.Markup(r"\bold { over pressure }"),
+            ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
             ...    )
             >>> for line in override.override_format_pieces:
             ...     line
             ...
-            '\\once \\override Staff.TextSpanner.bound-details.left.text = \\markup {'
-            '    \\bold'
-            '        {'
-            '            over'
-            '            pressure'
-            '        }'
-            '    }'
+            '\\once \\override Staff.TextSpanner.bound-details.left.text = \\markup \\bold { over pressure }'
 
         """
         result = []
@@ -935,7 +919,7 @@ class LilyPondOverride:
             ...        "left",
             ...        "text",
             ...        ),
-            ...    value=abjad.Markup(r"\bold { over pressure }"),
+            ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
             ...    )
             >>> override.property_path
             ('bound-details', 'left', 'text')
@@ -996,10 +980,10 @@ class LilyPondOverride:
             ...        "left",
             ...        "text",
             ...        ),
-            ...    value=abjad.Markup(r"\markup \bold { over pressure }", literal=True),
+            ...    value=abjad.Markup(r"\markup \bold { over pressure }"),
             ...    )
             >>> override.value
-            Markup(contents=['\\markup \\bold { over pressure }'], literal=True)
+            Markup(string='\\markup \\bold { over pressure }', direction=None, tweaks=None)
 
         """
         return self._value
@@ -1117,15 +1101,13 @@ class LilyPondSetting:
     def __hash__(self) -> int:
         """
         Hashes LilyPond context setting.
-
-        Redefined in tandem with __eq__.
         """
         return super().__hash__()
 
     ### PRIVATE METHODS ###
 
     def _get_lilypond_format_bundle(self, component=None):
-        bundle = LilyPondFormatBundle()
+        bundle = _bundle.LilyPondFormatBundle()
         string = "\n".join(self.format_pieces)
         bundle.context_settings.append(string)
         return bundle
@@ -1230,7 +1212,7 @@ class OverrideInterface(Interface):
         Note that the dot-chained user syntax is unproblematic. But the class of each
         manager returned in the chain is likely to be surprising at first encounter.
         """
-        camel_name = String(name).to_upper_camel_case()
+        camel_name = _string.String(name).to_upper_camel_case()
         # assert name == camel_name, repr((name, camel_name))
         if name.startswith("_"):
             try:
@@ -1238,14 +1220,14 @@ class OverrideInterface(Interface):
             except KeyError:
                 type_name = type(self).__name__
                 raise AttributeError("{type_name!r} object has no attribute: {name!r}.")
-        elif camel_name in contexts:
+        elif camel_name in _lyenv.contexts:
             try:
                 return vars(self)["_" + name]
             except KeyError:
                 context = OverrideInterface()
                 vars(self)["_" + name] = context
                 return context
-        elif camel_name in grob_interfaces:
+        elif camel_name in _lyenv.grob_interfaces:
             try:
                 return vars(self)[name]
             except KeyError:
@@ -1284,6 +1266,7 @@ class OverrideInterface(Interface):
                     for attribute, value in pairs:
                         quadruple = (context, grob, attribute, value)
                         result.append(quadruple)
+        result.sort()
         return tuple(result)
 
     def _list_format_contributions(self, contribution_type, once=False):
@@ -1403,7 +1386,8 @@ class SettingInterface(Interface):
         ..  container:: example
 
             >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> abjad.setting(staff).instrumentName = abjad.Markup("Vn. I")
+            >>> markup = abjad.Markup(r'\markup "Vn. I"')
+            >>> abjad.setting(staff).instrumentName = markup
             >>> abjad.show(staff) # doctest: +SKIP
 
             ..  docs::
@@ -1413,7 +1397,7 @@ class SettingInterface(Interface):
                 \new Staff
                 \with
                 {
-                    instrumentName = \markup { Vn. I }
+                    instrumentName = \markup "Vn. I"
                 }
                 {
                     c'4
@@ -1427,10 +1411,10 @@ class SettingInterface(Interface):
             Returns arbitrary object keyed to ``name``:
 
             >>> abjad.setting(staff).instrumentName
-            Markup(contents=['Vn. I'])
+            Markup(string='\\markup "Vn. I"', direction=None, tweaks=None)
 
         """
-        camel_name = String(name).to_upper_camel_case()
+        camel_name = _string.String(name).to_upper_camel_case()
         # assert name == camel_name, repr((name, camel_name))
         if name.startswith("_"):
             try:
@@ -1438,7 +1422,7 @@ class SettingInterface(Interface):
             except KeyError:
                 message = "{type(self).__name__!r} object has no attribute: {name!r}."
                 raise AttributeError(message)
-        elif camel_name in contexts:
+        elif camel_name in _lyenv.contexts:
             try:
                 return vars(self)["_" + name]
             except KeyError:
@@ -1470,7 +1454,7 @@ class SettingInterface(Interface):
             result = rf"{string!s} = {value_parts[0]!s}"
             pieces = [result]
             for part in value_parts[1:]:
-                pieces.append(LilyPondFormatBundle.indent + part)
+                pieces.append(_format.INDENT + part)
             string = "\n".join(pieces)
             strings.append(string)
         return strings
@@ -1524,6 +1508,7 @@ class SettingInterface(Interface):
             else:
                 attribute_name, attribute_value = name, value
                 result.append((attribute_name, attribute_value))
+        result.sort()
         return result
 
 
@@ -1539,7 +1524,8 @@ def setting(argument):
         Sets instrument name:
 
         >>> staff = abjad.Staff("c'4 e'4 d'4 f'4")
-        >>> abjad.setting(staff).instrumentName = abjad.Markup("Vn. I")
+        >>> markup = abjad.Markup(r'\markup "Vn. I"')
+        >>> abjad.setting(staff).instrumentName = markup
         >>> abjad.show(staff) # doctest: +SKIP
 
 
@@ -1550,7 +1536,7 @@ def setting(argument):
             \new Staff
             \with
             {
-                instrumentName = \markup { Vn. I }
+                instrumentName = \markup "Vn. I"
             }
             {
                 c'4
@@ -1564,7 +1550,7 @@ def setting(argument):
         Returns LilyPond setting name manager:
 
         >>> abjad.setting(staff)
-        SettingInterface(('instrumentName', Markup(contents=['Vn. I'])))
+        SettingInterface(('instrumentName', Markup(string='\\markup "Vn. I"', direction=None, tweaks=None)))
 
     """
     if getattr(argument, "_lilypond_setting_name_manager", None) is None:
@@ -1573,14 +1559,14 @@ def setting(argument):
 
 
 class TweakInterface(Interface):
-    """
+    r"""
     LilyPond tweak manager.
 
     ..  container:: example
 
         Tweak managers are created by the ``abjad.tweak()`` factory function:
 
-        >>> markup = abjad.Markup("Allegro", direction=abjad.Up)
+        >>> markup = abjad.Markup(r"\markup Allegro", direction=abjad.Up)
         >>> abjad.tweak(markup)
         TweakInterface(('_literal', None))
 
@@ -1632,7 +1618,7 @@ class TweakInterface(Interface):
             Tweaks may be tagged:
 
             >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> markup = abjad.Markup(r"\italic Allegro", direction=abjad.Up)
+            >>> markup = abjad.Markup(r"\markup \italic Allegro", direction=abjad.Up)
             >>> abjad.tweak(markup, tag=abjad.Tag("+PARTS")).color = "#red"
             >>> abjad.attach(markup, staff[0])
             >>> abjad.show(staff) # doctest: +SKIP
@@ -1642,11 +1628,9 @@ class TweakInterface(Interface):
             \new Staff
             {
                 c'4
-                - \tweak color #red %! +PARTS
-                ^ \markup {
-                    \italic
-                        Allegro
-                    }
+                %! +PARTS
+                - \tweak color #red
+                ^ \markup \italic Allegro
                 d'4
                 e'4
                 f'4
@@ -1655,7 +1639,7 @@ class TweakInterface(Interface):
             Tweaks may be tagged with ``deactivate=True``:
 
             >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> markup = abjad.Markup(r"\italic Allegro", direction=abjad.Up)
+            >>> markup = abjad.Markup(r"\markup \italic Allegro", direction=abjad.Up)
             >>> abjad.tweak(
             ...     markup, deactivate=True, tag=abjad.Tag("+PARTS")
             ... ).color = "#red"
@@ -1667,11 +1651,9 @@ class TweakInterface(Interface):
             \new Staff
             {
                 c'4
-                - \tweak color #red %! +PARTS
-                ^ \markup {
-                    \italic
-                        Allegro
-                    }
+                %! +PARTS
+                - \tweak color #red
+                ^ \markup \italic Allegro
                 d'4
                 e'4
                 f'4
@@ -1680,7 +1662,7 @@ class TweakInterface(Interface):
             Tweak tags and indicator tags may be set together:
 
             >>> staff = abjad.Staff("c'4 d' e' f'")
-            >>> markup = abjad.Markup(r"\italic Allegro", direction=abjad.Up)
+            >>> markup = abjad.Markup(r"\markup \italic Allegro", direction=abjad.Up)
             >>> abjad.tweak(markup, tag=abjad.Tag("+PARTS")).color = "#red"
             >>> abjad.attach(markup, staff[0], tag=abjad.Tag("RED:M1"))
             >>> abjad.show(staff) # doctest: +SKIP
@@ -1690,11 +1672,13 @@ class TweakInterface(Interface):
             \new Staff
             {
                 c'4
-                - \tweak color #red                 %! +PARTS
-                ^ \markup {                         %! RED:M1
-                    \italic                         %! RED:M1
-                        Allegro                     %! RED:M1
-                    }                               %! RED:M1
+                %! +PARTS
+                %! RED
+                %! M1
+                - \tweak color #red
+                %! RED
+                %! M1
+                ^ \markup \italic Allegro
                 d'4
                 e'4
                 f'4
@@ -1739,7 +1723,7 @@ class TweakInterface(Interface):
             self.__setattr__(name, _pending_value)
             delattr(self, "_pending_value")
             return self
-        camel_name = String(name).to_upper_camel_case()
+        camel_name = _string.String(name).to_upper_camel_case()
         # assert name == camel_name, repr((name, camel_name))
         if name.startswith("_"):
             try:
@@ -1747,7 +1731,7 @@ class TweakInterface(Interface):
             except KeyError:
                 type_name = type(self).__name__
                 raise AttributeError(f"{type_name} object has no attribute {name!r}.")
-        elif camel_name in grob_interfaces:
+        elif camel_name in _lyenv.grob_interfaces:
             try:
                 return vars(self)[name]
             except KeyError:
@@ -1815,6 +1799,7 @@ class TweakInterface(Interface):
                 attribute_value = value
                 pair = (attribute_name, attribute_value)
                 result.append(pair)
+        result.sort()
         return result
 
     def _list_format_contributions(self, directed=True):
@@ -1845,12 +1830,10 @@ class TweakInterface(Interface):
                 grob=grob,
                 literal=self._literal,
             )
+            strings = [string]
             if tag is not None:
-                strings = [string]
-                strings = _tag.tag(strings, deactivate=deactivate, tag=tag)
-                string = strings[0]
-            result.append(string)
-        result.sort()
+                strings = _tag.double_tag(strings, tag, deactivate=deactivate)
+            result.extend(strings)
         return result
 
     ### PUBLIC METHODS ###
@@ -1863,19 +1846,6 @@ class TweakInterface(Interface):
         r"""
         Sets tweaks on ``argument``.
 
-        ..  container:: example
-
-            >>> glissando = abjad.Glissando()
-            >>> glissando.tweaks is None
-            True
-
-            >>> tweaks = abjad.tweak("blue").color
-            >>> abjad.TweakInterface.set_tweaks(glissando, tweaks)
-            TweakInterface(('_literal', None), ('color', 'blue'))
-
-            >>> abjad.tweak(glissando)
-            TweakInterface(('_literal', None), ('color', 'blue'))
-
         """
         if not hasattr(argument, "_tweaks"):
             try:
@@ -1906,6 +1876,52 @@ class TweakInterface(Interface):
                 raise ValueError(message)
         return existing_manager
 
+    # TODO: move this somewhere clearer
+    @staticmethod
+    def set_dataclass_tweaks(
+        argument, manager: typing.Optional["TweakInterface"]
+    ) -> typing.Optional["TweakInterface"]:
+        """
+        Sets tweaks on ``argument``.
+
+        ..  container:: example
+
+            >>> glissando = abjad.Glissando()
+            >>> glissando.tweaks is None
+            True
+
+            >>> tweaks = abjad.tweak("blue").color
+            >>> abjad.TweakInterface.set_dataclass_tweaks(glissando, tweaks)
+            TweakInterface(('_literal', None), ('color', 'blue'))
+
+            >>> abjad.tweak(glissando)
+            TweakInterface(('_literal', None), ('color', 'blue'))
+
+        """
+        assert argument._is_dataclass is True, repr(argument)
+        if manager is None:
+            return None
+        if not isinstance(manager, TweakInterface):
+            raise Exception(f"must be tweak manager (not {manager!r}).")
+        if argument.tweaks is None:
+            argument.tweaks = TweakInterface(literal=manager._literal)
+        existing_manager = argument.tweaks
+        for tuple_ in manager._get_attribute_tuples():
+            if len(tuple_) == 2:
+                attribute, value = tuple_
+                value = copy.copy(value)
+                setattr(existing_manager, attribute, value)
+            elif len(tuple_) == 3:
+                grob, attribute, value = tuple_
+                value = copy.copy(value)
+                grob = getattr(existing_manager, grob)
+                setattr(grob, attribute, value)
+            else:
+                message = "tweak tuple must have length 2 or 3"
+                message += f" (not {tuple_!r})."
+                raise ValueError(message)
+        return existing_manager
+
 
 IndexedTweakManager = typing.Union[TweakInterface, typing.Tuple[TweakInterface, int]]
 
@@ -1924,7 +1940,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         Tweaks markup:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> markup = abjad.Markup("Allegro assai", direction=abjad.Up)
+        >>> markup = abjad.Markup(r'\markup "Allegro assai"', direction=abjad.Up)
         >>> abjad.tweak(markup).color = "#red"
         >>> abjad.attach(markup, staff[0])
         >>> abjad.show(staff) # doctest: +SKIP
@@ -1937,7 +1953,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
             {
                 c'4
                 - \tweak color #red
-                ^ \markup { Allegro assai }
+                ^ \markup "Allegro assai"
                 d'4
                 e'4
                 f'4
@@ -1947,7 +1963,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
 
         >>> import copy
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> markup_1 = abjad.Markup("Allegro assai", direction=abjad.Up)
+        >>> markup_1 = abjad.Markup(r'\markup "Allegro assai"', direction=abjad.Up)
         >>> abjad.tweak(markup_1).color = "#red"
         >>> markup_2 = copy.copy(markup_1)
         >>> abjad.attach(markup_2, staff[0])
@@ -1961,7 +1977,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
             {
                 c'4
                 - \tweak color #red
-                ^ \markup { Allegro assai }
+                ^ \markup "Allegro assai"
                 d'4
                 e'4
                 f'4
@@ -1970,7 +1986,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         Survives dot-chaining:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> markup = abjad.Markup(r'\italic "Allegro assai"', direction=abjad.Up)
+        >>> markup = abjad.Markup(r'\markup \italic "Allegro assai"', direction=abjad.Up)
         >>> abjad.tweak(markup).color = "#red"
         >>> abjad.attach(markup, staff[0])
         >>> abjad.show(staff) # doctest: +SKIP
@@ -1983,10 +1999,7 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
             {
                 c'4
                 - \tweak color #red
-                ^ \markup {
-                    \italic
-                        "Allegro assai"
-                    }
+                ^ \markup \italic "Allegro assai"
                 d'4
                 e'4
                 f'4
@@ -1995,10 +2008,10 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         Works for opposite-directed coincident markup:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> markup_1 = abjad.Markup("Allegro assai ...", direction=abjad.Up)
+        >>> markup_1 = abjad.Markup(r'\markup "Allegro assai ..."', direction=abjad.Up)
         >>> abjad.tweak(markup_1).color = "#red"
         >>> abjad.attach(markup_1, staff[0])
-        >>> markup_2 = abjad.Markup("... ma non troppo", direction=abjad.Down)
+        >>> markup_2 = abjad.Markup(r'\markup "... ma non troppo"', direction=abjad.Down)
         >>> abjad.tweak(markup_2).color = "#blue"
         >>> abjad.tweak(markup_2).staff_padding = 4
         >>> abjad.attach(markup_2, staff[0])
@@ -2012,10 +2025,10 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
             {
                 c'4
                 - \tweak color #red
-                ^ \markup { Allegro assai ... }
+                ^ \markup "Allegro assai ..."
                 - \tweak color #blue
                 - \tweak staff-padding 4
-                _ \markup { ... ma non troppo }
+                _ \markup "... ma non troppo"
                 d'4
                 e'4
                 f'4
@@ -2024,10 +2037,10 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         Ignored for same-directed coincident markup:
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
-        >>> markup_1 = abjad.Markup("Allegro assai ...", direction=abjad.Up)
+        >>> markup_1 = abjad.Markup(r'\markup "Allegro assai ..."', direction=abjad.Up)
         >>> abjad.tweak(markup_1).color = "#red"
         >>> abjad.attach(markup_1, staff[0])
-        >>> markup_2 = abjad.Markup("... ma non troppo", direction=abjad.Up)
+        >>> markup_2 = abjad.Markup(r'\markup "... ma non troppo"', direction=abjad.Up)
         >>> abjad.tweak(markup_2).color = "#blue"
         >>> abjad.tweak(markup_2).staff_padding = 4
         >>> abjad.attach(markup_2, staff[0])
@@ -2041,10 +2054,10 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
             {
                 c'4
                 - \tweak color #red
-                ^ \markup { Allegro assai ... }
+                ^ \markup "Allegro assai ..."
                 - \tweak color #blue
                 - \tweak staff-padding 4
-                ^ \markup { ... ma non troppo }
+                ^ \markup "... ma non troppo"
                 d'4
                 e'4
                 f'4
@@ -2104,7 +2117,8 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         \new Staff
         {
             c'4
-            - \tweak color #red %! RED
+            %! RED
+            - \tweak color #red
             \f
             d'4
             e'4
@@ -2126,7 +2140,8 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
         \new Staff
         {
             c'4
-            - \tweak color #blue %! BLUE
+            %! BLUE
+            - \tweak color #blue
             \f
             d'4
             e'4
@@ -2158,20 +2173,27 @@ def tweak(argument, *, deactivate=None, expression=None, literal=None, tag=None)
     """
     if tag is not None and not isinstance(tag, _tag.Tag):
         raise Exception(f"must be be tag: {repr(tag)}")
-
-    constants = (enums.Down, enums.Left, enums.Right, enums.Up)
+    constants = (_enums.Down, _enums.Left, _enums.Right, _enums.Up)
     prototype = (bool, int, float, str, tuple)
     if expression is True or argument in constants or isinstance(argument, prototype):
         interface = TweakInterface(deactivate=deactivate, literal=literal, tag=tag)
         interface._pending_value = argument
         return interface
-    if not hasattr(argument, "_tweaks"):
-        name = type(argument).__name__
-        raise NotImplementedError(f"{name} does not allow tweaks (yet).")
-    if argument._tweaks is None:
-        interface = TweakInterface(deactivate=deactivate, literal=literal, tag=tag)
-        argument._tweaks = interface
+    if getattr(argument, "_is_dataclass", False) is True:
+        if argument.tweaks is None:
+            interface = TweakInterface(deactivate=deactivate, literal=literal, tag=tag)
+            argument.tweaks = interface
+        else:
+            interface = argument.tweaks
+            interface.__init__(deactivate=deactivate, literal=literal, tag=tag)
     else:
-        interface = argument._tweaks
-        interface.__init__(deactivate=deactivate, literal=literal, tag=tag)
+        if not hasattr(argument, "_tweaks"):
+            name = type(argument).__name__
+            raise NotImplementedError(f"{name} does not allow tweaks (yet).")
+        if argument._tweaks is None:
+            interface = TweakInterface(deactivate=deactivate, literal=literal, tag=tag)
+            argument._tweaks = interface
+        else:
+            interface = argument._tweaks
+            interface.__init__(deactivate=deactivate, literal=literal, tag=tag)
     return interface
