@@ -1,19 +1,10 @@
 import collections
 import typing
 
-from . import math
-from .duration import Multiplier
-from .ordereddict import OrderedDict
-from .score import (
-    AfterGraceContainer,
-    BeforeGraceContainer,
-    Component,
-    Score,
-    Staff,
-    StaffGroup,
-    Voice,
-)
-from .storage import StorageFormatManager
+from . import duration as _duration
+from . import format as _format
+from . import math as _math
+from . import score as _score
 
 
 class Parentage(collections.abc.Sequence):
@@ -79,7 +70,7 @@ class Parentage(collections.abc.Sequence):
     def __init__(self, component=None):
         components = []
         if component is not None:
-            assert isinstance(component, Component), repr(component)
+            assert isinstance(component, _score.Component), repr(component)
             components.extend(component._get_parentage())
         self._component = component
         self._components = tuple(components)
@@ -104,7 +95,7 @@ class Parentage(collections.abc.Sequence):
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE METHODS ###
 
@@ -116,7 +107,7 @@ class Parentage(collections.abc.Sequence):
 
     def _prolations(self):
         prolations = []
-        default = Multiplier(1)
+        default = _duration.Multiplier(1)
         for parent in self:
             prolation = getattr(parent, "implied_prolation", default)
             prolations.append(prolation)
@@ -125,7 +116,7 @@ class Parentage(collections.abc.Sequence):
     ### PUBLIC PROPERTIES ###
 
     @property
-    def component(self) -> Component:
+    def component(self) -> _score.Component:
         r"""
         Gets component.
 
@@ -143,7 +134,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -219,7 +211,7 @@ class Parentage(collections.abc.Sequence):
         return self._component
 
     @property
-    def components(self) -> typing.Tuple[Component]:
+    def components(self) -> typing.Tuple[_score.Component]:
         r"""
         Gets components.
 
@@ -237,7 +229,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -396,7 +389,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -472,7 +466,7 @@ class Parentage(collections.abc.Sequence):
         return self.parent is None
 
     @property
-    def parent(self) -> typing.Optional[Component]:
+    def parent(self) -> typing.Optional[_score.Component]:
         r"""
         Gets parent.
 
@@ -490,7 +484,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -566,7 +561,7 @@ class Parentage(collections.abc.Sequence):
         return self.get(n=1)
 
     @property
-    def prolation(self) -> Multiplier:
+    def prolation(self) -> _duration.Multiplier:
         r"""
         Gets prolation.
 
@@ -588,7 +583,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[1][2])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -666,12 +662,12 @@ class Parentage(collections.abc.Sequence):
             Note("fs'16")                  Multiplier(2, 3)
 
         """
-        prolations = [Multiplier(1)] + self._prolations()
-        products = math.cumulative_products(prolations)
+        prolations = [_duration.Multiplier(1)] + self._prolations()
+        products = _math.cumulative_products(prolations)
         return products[-1]
 
     @property
-    def root(self) -> Component:
+    def root(self) -> _score.Component:
         r"""
         Gets root.
 
@@ -689,7 +685,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -763,7 +760,7 @@ class Parentage(collections.abc.Sequence):
 
         """
         root = self.get(n=-1)
-        assert isinstance(root, Component), repr(root)
+        assert isinstance(root, _score.Component), repr(root)
         return root
 
     ### PUBLIC METHODS ###
@@ -877,7 +874,7 @@ class Parentage(collections.abc.Sequence):
                     d''8
                 }
 
-            >>> for leaf in abjad.iterate(outer_red_voice).leaves():
+            >>> for leaf in abjad.iterate.leaves(outer_red_voice):
             ...     depth = abjad.get.parentage(leaf).count(abjad.Voice)
             ...     print(leaf, depth)
             ...
@@ -905,7 +902,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -981,13 +979,13 @@ class Parentage(collections.abc.Sequence):
         """
         n = 0
         if prototype is None:
-            prototype = Component
+            prototype = _score.Component
         for component in self:
             if isinstance(component, prototype):
                 n += 1
         return n
 
-    def get(self, prototype=None, n=0) -> typing.Optional[Component]:
+    def get(self, prototype=None, n=0) -> typing.Optional[_score.Component]:
         r"""
         Gets instance ``n`` of ``prototype`` in parentage.
 
@@ -1161,7 +1159,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -1236,7 +1235,7 @@ class Parentage(collections.abc.Sequence):
 
         """
         if prototype is None:
-            prototype = (Component,)
+            prototype = (_score.Component,)
         if not isinstance(prototype, tuple):
             prototype = (prototype,)
         if 0 <= n:
@@ -1255,7 +1254,7 @@ class Parentage(collections.abc.Sequence):
                     i -= 1
         return None
 
-    def logical_voice(self) -> OrderedDict:
+    def logical_voice(self) -> dict:
         r"""
         Gets logical voice.
 
@@ -1291,13 +1290,13 @@ class Parentage(collections.abc.Sequence):
             >>> logical_voice = parentage.logical_voice()
             >>> string = abjad.storage(logical_voice)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', "Score-'Score'"),
-                    ('staff', "Staff-'Music_Staff'"),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': "Score-'Score'",
+                    'staff': "Staff-'Music_Staff'",
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
         ..  container:: example
@@ -1333,71 +1332,71 @@ class Parentage(collections.abc.Sequence):
             >>> lv = abjad.get.parentage(voice).logical_voice()
             >>> string = abjad.storage(lv)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', ''),
-                    ('staff', ''),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': '',
+                    'staff': '',
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
             >>> lv = abjad.get.parentage(container_1).logical_voice()
             >>> string = abjad.storage(lv)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', ''),
-                    ('staff', ''),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': '',
+                    'staff': '',
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
             >>> lv = abjad.get.parentage(container_1[0]).logical_voice()
             >>> string = abjad.storage(lv)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', ''),
-                    ('staff', ''),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': '',
+                    'staff': '',
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
             >>> lv = abjad.get.parentage(container_2).logical_voice()
             >>> string = abjad.storage(lv)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', ''),
-                    ('staff', ''),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': '',
+                    'staff': '',
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
             >>> lv = abjad.get.parentage(container_2[0]).logical_voice()
             >>> string = abjad.storage(lv)
             >>> print(string)
-            abjad.OrderedDict(
-                [
-                    ('score', ''),
-                    ('staff', ''),
-                    ('staff group', ''),
-                    ('voice', "Voice-'Music_Voice'"),
-                    ]
+            dict(
+                {
+                    'score': '',
+                    'staff': '',
+                    'staff group': '',
+                    'voice': "Voice-'Music_Voice'",
+                    }
                 )
 
         """
         keys = ("score", "staff group", "staff", "voice")
-        logical_voice = collections.OrderedDict.fromkeys(keys, "")
+        logical_voice = dict.fromkeys(keys, "")
         for component in self:
-            if isinstance(component, Voice):
+            if isinstance(component, _score.Voice):
                 if not logical_voice["voice"]:
                     logical_voice["voice"] = self._id_string(component)
-            elif isinstance(component, Staff):
+            elif isinstance(component, _score.Staff):
                 if not logical_voice["staff"]:
                     logical_voice["staff"] = self._id_string(component)
                     # explicit staff demands a nested voice:
@@ -1405,13 +1404,13 @@ class Parentage(collections.abc.Sequence):
                     # create implicit voice here with random integer
                     if not logical_voice["voice"]:
                         logical_voice["voice"] = str(id(component))
-            elif isinstance(component, StaffGroup):
+            elif isinstance(component, _score.StaffGroup):
                 if not logical_voice["staff group"]:
                     logical_voice["staff group"] = self._id_string(component)
-            elif isinstance(component, Score):
+            elif isinstance(component, _score.Score):
                 if not logical_voice["score"]:
                     logical_voice["score"] = self._id_string(component)
-        logical_voice_ = OrderedDict(logical_voice)
+        logical_voice_ = dict(logical_voice)
         return logical_voice_
 
     def score_index(self) -> typing.Tuple[typing.Union[int, str], ...]:
@@ -1476,7 +1475,8 @@ class Parentage(collections.abc.Sequence):
             >>> container = abjad.AfterGraceContainer("fs'16")
             >>> abjad.attach(container, music_voice[3])
             >>> staff = abjad.Staff([music_voice])
-            >>> abjad.show(staff) # doctest: +SKIP
+            >>> lilypond_file = abjad.LilyPondFile([r'\include "abjad.ily"', staff])
+            >>> abjad.show(lilypond_file) # doctest: +SKIP
 
             ..  docs::
 
@@ -1553,11 +1553,11 @@ class Parentage(collections.abc.Sequence):
         result: typing.List[typing.Union[int, str]] = []
         current = self[0]
         for parent in self[1:]:
-            if isinstance(current, BeforeGraceContainer):
+            if isinstance(current, _score.BeforeGraceContainer):
                 tuple_ = type(self)(current._main_leaf).score_index()
                 list_ = list(tuple_) + ["-G"]
                 result[0:0] = list_
-            elif isinstance(current, AfterGraceContainer):
+            elif isinstance(current, _score.AfterGraceContainer):
                 tuple_ = type(self)(current._main_leaf).score_index()
                 list_ = list(tuple_) + ["+G"]
                 result[0:0] = list_
