@@ -8,14 +8,15 @@ import quicktions
 import uqbar.containers
 import uqbar.graphs
 
-from . import math, mutate
-from .duration import Duration, Multiplier, NonreducedFraction, Offset
-from .makers import LeafMaker
+from . import duration as _duration
+from . import format as _format
+from . import makers as _makers
+from . import math as _math
+from . import mutate as _mutate
+from . import score as _score
+from . import sequence as _sequence
+from . import spanners as _spanners
 from .parsers.base import Parser
-from .score import Container, Tuplet
-from .sequence import Sequence
-from .spanners import tie
-from .storage import FormatSpecification, StorageFormatManager
 
 
 class RhythmTreeMixin:
@@ -32,7 +33,7 @@ class RhythmTreeMixin:
     @abc.abstractmethod
     def __init__(self, preprolated_duration=1):
         self._duration = 0
-        self._offset = Offset(0)
+        self._offset = _duration.Offset(0)
         self._offsets_are_current = False
         self.preprolated_duration = preprolated_duration
 
@@ -49,7 +50,7 @@ class RhythmTreeMixin:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE METHODS ###
 
@@ -67,7 +68,7 @@ class RhythmTreeMixin:
         return inventory
 
     def _get_format_specification(self):
-        return FormatSpecification(client=self)
+        return _format.FormatSpecification()
 
     @abc.abstractmethod
     def _pretty_rtm_format_pieces(self):
@@ -86,7 +87,7 @@ class RhythmTreeMixin:
                     current_offset += child.duration
             return current_offset
 
-        offset = Offset(0)
+        offset = _duration.Offset(0)
         root = self.root
         if root is None:
             root = self
@@ -195,7 +196,7 @@ class RhythmTreeMixin:
     @preprolated_duration.setter
     def preprolated_duration(self, argument):
         if not isinstance(argument, quicktions.Fraction):
-            argument = Duration(argument)
+            argument = _duration.Duration(argument)
         assert 0 < argument
         self._duration = argument
         self._mark_entire_tree_for_later_update()
@@ -227,7 +228,7 @@ class RhythmTreeMixin:
 
         Returns multiplier.
         """
-        return math.cumulative_products(self.prolations)[-1]
+        return _math.cumulative_products(self.prolations)[-1]
 
     @property
     def prolations(self):
@@ -236,11 +237,13 @@ class RhythmTreeMixin:
 
         Returns tuple.
         """
-        prolations = [Multiplier(1)]
-        pairs = Sequence(self.parentage).nwise()
+        prolations = [_duration.Multiplier(1)]
+        pairs = _sequence.Sequence(self.parentage).nwise()
         for child, parent in pairs:
             prolations.append(
-                Multiplier(parent.preprolated_duration, parent._get_contents_duration())
+                _duration.Multiplier(
+                    parent.preprolated_duration, parent._get_contents_duration()
+                )
             )
         return tuple(prolations)
 
@@ -336,9 +339,9 @@ class RhythmTreeLeaf(RhythmTreeMixin, uqbar.containers.UniqueTreeNode):
 
         Returns sequence of components.
         """
-        pulse_duration = Duration(pulse_duration)
+        pulse_duration = _duration.Duration(pulse_duration)
         total_duration = pulse_duration * self.preprolated_duration
-        maker = LeafMaker()
+        maker = _makers.LeafMaker()
         if self.is_pitched:
             return maker(0, total_duration)
         return maker([None], total_duration)
@@ -490,9 +493,11 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
 
             >>> string = abjad.lilypond(tuplet)
             >>> print(string)
-            \times 2/3 {
+            \times 2/3
+            {
                 c'8
-                \times 4/5 {
+                \times 4/5
+                {
                     c'8.
                     c'8
                 }
@@ -592,9 +597,11 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
                 >>> print(string)
                 \new Staff
                 {
-                    \times 4/5 {
+                    \times 4/5
+                    {
                         c'16
-                        \times 2/3 {
+                        \times 2/3
+                        {
                             c'16
                             c'16
                             c'16
@@ -611,7 +618,7 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
             basic_written_duration = (
                 basic_prolated_duration.equal_or_greater_power_of_two
             )
-            tuplet = Tuplet(1, [])
+            tuplet = _score.Tuplet(1, [])
             for child in node.children:
                 if isinstance(child, type(self)):
                     tuplet.extend(
@@ -624,7 +631,7 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
                     leaves = child(basic_written_duration)
                     tuplet.extend(leaves)
                     if 1 < len(leaves):
-                        tie(leaves)
+                        _spanners.tie(leaves)
             assert tuplet.multiplier == 1, repr(tuplet.multiplier)
             contents_duration = tuplet._get_duration()
             target_duration = tuplet_duration
@@ -634,13 +641,13 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
                 return tuplet[:]
             return [tuplet]
 
-        pulse_duration = Duration(pulse_duration)
+        pulse_duration = _duration.Duration(pulse_duration)
         assert 0 < pulse_duration
         result = recurse(self, pulse_duration * self.preprolated_duration)
         for component in result[:]:
-            if isinstance(component, Tuplet):
+            if isinstance(component, _score.Tuplet):
                 if component.trivial():
-                    mutate._extract(component)
+                    _mutate._extract(component)
         return result
 
     def __graph__(self, **keywords):
@@ -762,14 +769,6 @@ class RhythmTreeContainer(RhythmTreeMixin, uqbar.containers.UniqueTreeList):
         result[-1] = result[-1] + "))"
         return result
 
-    #    @property
-    #    def _leaf_class(self):
-    #        return RhythmTreeLeaf
-
-    #    @property
-    #    def _node_class(self):
-    #        return RhythmTreeMixin
-
     ### PUBLIC PROPERTIES ###
 
     @property
@@ -841,7 +840,8 @@ class RhythmTreeParser(Parser):
                         abjad.rhythmtrees.RhythmTreeLeaf(
                             preprolated_duration=abjad.Duration(2, 1),
                             is_pitched=True,
-                            ), abjad.rhythmtrees.RhythmTreeLeaf(
+                            ),
+                        abjad.rhythmtrees.RhythmTreeLeaf(
                             preprolated_duration=abjad.Duration(1, 1),
                             is_pitched=True,
                             ),
@@ -862,10 +862,13 @@ class RhythmTreeParser(Parser):
             >>> string = abjad.lilypond(tuplet)
             >>> print(string)
             \tweak text #tuplet-number::calc-fraction-text
-            \times 3/4 {
+            \times 3/4
+            {
                 c'2
-                \times 4/7 {
-                    \times 2/3 {
+                \times 4/7
+                {
+                    \times 2/3
+                    {
                         c'8
                         c'8
                         c'8
@@ -906,11 +909,11 @@ class RhythmTreeParser(Parser):
         r"-?[1-9]\d*(/[1-9]\d*)?"
         parts = t.value.partition("/")
         if not parts[2]:
-            t.value = Duration(int(parts[0]))
+            t.value = _duration.Duration(int(parts[0]))
         else:
             numerator, denominator = int(parts[0]), int(parts[2])
-            fraction = NonreducedFraction(numerator, denominator)
-            preprolated_duration = Duration(fraction)
+            fraction = _duration.NonreducedFraction(numerator, denominator)
+            preprolated_duration = _duration.Duration(fraction)
             if fraction.numerator == preprolated_duration.numerator:
                 t.value = preprolated_duration
             else:
@@ -1010,7 +1013,8 @@ def parse_rtm_syntax(rtm):
 
             >>> string = abjad.lilypond(tuplet)
             >>> print(string)
-            \times 2/3 {
+            \times 2/3
+            {
                 c'8
                 c'16
                 c'16
@@ -1030,11 +1034,13 @@ def parse_rtm_syntax(rtm):
             >>> string = abjad.lilypond(tuplet)
             >>> print(string)
             \tweak text #tuplet-number::calc-fraction-text
-            \times 9/17 {
+            \times 9/17
+            {
                 c'8
                 c'16
                 \tweak edge-height #'(0.7 . 0)
-                \times 8/15 {
+                \times 8/15
+                {
                     c'8
                     r16
                     c'8
@@ -1044,7 +1050,7 @@ def parse_rtm_syntax(rtm):
     Returns tuplet or container.
     """
     result = RhythmTreeParser()(rtm)
-    container = Container()
+    container = _score.Container()
     for node in result:
         tuplet = node((1, 4))
         # following line added 2012-08-01. tb.
