@@ -1,6 +1,6 @@
 import typing
 
-from .storage import FormatSpecification, StorageFormatManager
+from . import format as _format
 
 
 class Tag:
@@ -42,10 +42,10 @@ class Tag:
 
         >>> abjad.Tag("+SEGMENT:-PARTS")
         Traceback (most recent call last):
-            ...
+        ...
         Exception: only-edition and not-edition forbidden in same tag:
         <BLANKLINE>
-        ['+SEGMENT'] / ['-PARTS']
+          ['+SEGMENT'] / ['-PARTS']
 
     """
 
@@ -176,7 +176,7 @@ class Tag:
             True
 
         """
-        return hash(str(self))
+        return hash(self.__class__.__name__ + str(self))
 
     def __iter__(self):
         """
@@ -199,7 +199,7 @@ class Tag:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     def __str__(self):
         """
@@ -222,11 +222,9 @@ class Tag:
         values = []
         if self.string is not None:
             values.append(self.string)
-        return FormatSpecification(
-            self,
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             storage_format_args_values=values,
-            storage_format_is_indented=False,
+            storage_format_is_not_indented=True,
         )
 
     ### PUBLIC PROPERTIES ###
@@ -420,7 +418,7 @@ class Line:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     def __str__(self):
         r"""
@@ -627,6 +625,14 @@ class Line:
 ### FUNCTIONS ###
 
 
+def _match_line(line, tag, current_tags):
+    if tag in current_tags:
+        return True
+    if callable(tag):
+        return tag(current_tags)
+    return False
+
+
 def activate(text, tag, skipped=False):
     r"""
     Activates ``tag`` in ``text``.
@@ -638,20 +644,22 @@ def activate(text, tag, skipped=False):
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
         >>> string = r"\markup { \with-color #red Allegro }"
-        >>> markup = abjad.Markup(string, literal=True)
+        >>> markup = abjad.Markup(string)
         >>> abjad.attach(
         ...     markup,
         ...     staff[0],
         ...     deactivate=True,
         ...     tag=abjad.Tag("RED_MARKUP"),
-        ...     )
+        ... )
 
         >>> text = abjad.lilypond(staff, tags=True)
-        >>> text = abjad.LilyPondFormatManager.left_shift_tags(text)
+        >>> text = abjad.lilypondformat.left_shift_tags(text)
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-        %@% - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+            %@% - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -663,9 +671,11 @@ def activate(text, tag, skipped=False):
 
         >>> text, count = abjad.activate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            - \markup { \with-color #red Allegro }               %! RED_MARKUP %@%
+            %! RED_MARKUP
+                - \markup { \with-color #red Allegro } %@%
             d'4
             e'4
             f'4
@@ -673,16 +683,18 @@ def activate(text, tag, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         Deactivates tag again:
 
         >>> text, count = abjad.deactivate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            %@% - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+            %@% - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -690,16 +702,18 @@ def activate(text, tag, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         Activates tag again:
 
         >>> text, count = abjad.activate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            - \markup { \with-color #red Allegro }               %! RED_MARKUP %@%
+            %! RED_MARKUP
+                - \markup { \with-color #red Allegro } %@%
             d'4
             e'4
             f'4
@@ -707,7 +721,7 @@ def activate(text, tag, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
     Tags can toggle indefinitely.
@@ -723,14 +737,21 @@ def activate(text, tag, skipped=False):
     text_lines = text.split("\n")
     text_lines = [_ + "\n" for _ in text_lines[:-1]] + text_lines[-1:]
     lines = []
+    current_tags = []
     for line in text_lines:
-        first_nonwhitespace_index = len(line) - len(line.lstrip())
-        index = first_nonwhitespace_index
-        if not Line(line).match(tag):
+        if line.lstrip().startswith("%! "):
+            lines.append(line)
+            current_tag = Tag(line.strip()[3:])
+            current_tags.append(current_tag)
+            continue
+        if not _match_line(line, tag, current_tags):
             lines.append(line)
             treated_last_line = False
             found_already_active_on_last_line = False
+            current_tags = []
             continue
+        first_nonwhitespace_index = len(line) - len(line.lstrip())
+        index = first_nonwhitespace_index
         if line[index : index + 4] in ("%%% ", "%@% "):
             if "%@% " in line:
                 line = line.replace("%@%", "   ")
@@ -751,6 +772,7 @@ def activate(text, tag, skipped=False):
             found_already_active_on_last_line = True
             treated_last_line = False
         lines.append(line)
+        current_tags = []
     text = "".join(lines)
     if skipped is True:
         return text, count, skipped_count
@@ -768,7 +790,7 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
 
         >>> staff = abjad.Staff("c'4 d' e' f'")
         >>> string = r"\markup { \with-color #red Allegro }"
-        >>> markup = abjad.Markup(string, literal=True)
+        >>> markup = abjad.Markup(string)
         >>> abjad.attach(
         ...     markup,
         ...     staff[0],
@@ -776,11 +798,13 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
         ...     )
 
         >>> text = abjad.lilypond(staff, tags=True)
-        >>> text = abjad.LilyPondFormatManager.left_shift_tags(text)
+        >>> text = abjad.lilypondformat.left_shift_tags(text)
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+            - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -793,9 +817,11 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
         >>> text = abjad.lilypond(staff, tags=True)
         >>> text, count = abjad.deactivate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            %%% - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+        %%% - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -803,16 +829,18 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         Activates tag again:
 
         >>> text, count = abjad.activate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+            - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -820,16 +848,18 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
         Deactivates tag again:
 
         >>> text, count = abjad.deactivate(text, abjad.Tag("RED_MARKUP"))
         >>> print(text)
-        \new Staff {
+        \new Staff
+        {
             c'4
-            %%% - \markup { \with-color #red Allegro }               %! RED_MARKUP
+            %! RED_MARKUP
+        %%% - \markup { \with-color #red Allegro }
             d'4
             e'4
             f'4
@@ -837,7 +867,7 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
 
         >>> lines = [_.strip("\n") for _ in text.split("\n")]
         >>> string = "\n".join(lines)
-        >>> lilypond_file = abjad.LilyPondFile(items=[string])
+        >>> lilypond_file = abjad.LilyPondFile([string])
         >>> abjad.show(lilypond_file) # doctest: +SKIP
 
     Tags can toggle indefinitely.
@@ -854,14 +884,21 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
     text_lines = [_ + "\n" for _ in text_lines[:-1]] + text_lines[-1:]
     lines = []
     previous_line_was_tweak = False
+    current_tags = []
     for line in text_lines:
-        first_nonwhitespace_index = len(line) - len(line.lstrip())
-        index = first_nonwhitespace_index
-        if not Line(line).match(tag):
+        if line.lstrip().startswith("%! "):
+            lines.append(line)
+            current_tag = Tag(line.strip()[3:])
+            current_tags.append(current_tag)
+            continue
+        if not _match_line(line, tag, current_tags):
             lines.append(line)
             treated_last_line, last_index = False, None
             found_already_deactivated_on_last_line = False
+            current_tags = []
             continue
+        first_nonwhitespace_index = len(line) - len(line.lstrip())
+        index = first_nonwhitespace_index
         if line[index] != "%":
             if last_index is None:
                 last_index = index
@@ -888,6 +925,7 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
             treated_last_line = False
         lines.append(line)
         previous_line_was_tweak = "tweak" in line
+        current_tags = []
     text = "".join(lines)
     if skipped is True:
         return text, count, skipped_count
@@ -895,29 +933,21 @@ def deactivate(text, tag, prepend_empty_chord=False, skipped=False):
         return text, count
 
 
-def tag(strings, tag, deactivate=None) -> typing.List[str]:
-    """
-    Tags ``strings`` with ``tag``.
-    """
-    if not tag:
-        return strings
-    if not strings:
-        return strings
-    if deactivate is not None:
-        assert isinstance(deactivate, type(True)), repr(deactivate)
-    length = max([len(_) for _ in strings])
-    strings_ = []
-    for string in strings:
-        if "%!" in string and r"\tweak" in string:
-            strings_.append(string)
-            continue
-        if "%!" not in string:
-            pad = length - len(string)
-        else:
-            pad = 0
-        tag_ = pad * " " + " " + "%!" + " " + str(tag)
-        string = string + tag_
-        strings_.append(string)
+def double_tag(strings, tag_, deactivate=None):
+    before_tags = []
+    if tag_:
+        line = str(tag_)
+        lines = line.split(":")
+        lines = ["%! " + _ for _ in lines]
+        before_tags.extend(lines)
+    right_tagged_lines = strings
     if deactivate is True:
-        strings_ = ["%@% " + _ for _ in strings_]
-    return strings_
+        right_tagged_lines = ["%@% " + _ for _ in right_tagged_lines]
+    result = []
+    for right_tagged_line in right_tagged_lines:
+        if right_tagged_line.strip().startswith("%!"):
+            result.append(right_tagged_line)
+            continue
+        result.extend(before_tags)
+        result.append(right_tagged_line)
+    return result
