@@ -1,8 +1,8 @@
 import abc
 import collections.abc
 
-from .new import new
-from .storage import FormatSpecification, StorageFormatManager
+from . import format as _format
+from . import new as _new
 
 
 class TypedCollection:
@@ -53,8 +53,6 @@ class TypedCollection:
     def __hash__(self):
         """
         Hashes typed collection.
-
-        Redefined in tandem with __eq__.
         """
         return object.__hash__(self)
 
@@ -78,7 +76,7 @@ class TypedCollection:
         """
         Gets interpreter representation.
         """
-        return StorageFormatManager(self).get_repr_format()
+        return _format.get_repr(self)
 
     ### PRIVATE METHODS ###
 
@@ -93,12 +91,12 @@ class TypedCollection:
         return coerce_(item)
 
     def _get_format_specification(self):
-        names = list(StorageFormatManager(self).signature_keyword_names)
+        result = _format._inspect_signature(self)
+        signature_keyword_names = result[1]
+        names = list(signature_keyword_names)
         if "items" in names:
             names.remove("items")
-        return FormatSpecification(
-            self,
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             storage_format_args_values=[self._collection],
             storage_format_keyword_names=names,
         )
@@ -309,12 +307,12 @@ class TypedCounter(TypedCollection, collections.abc.MutableMapping):
         return the_items, itemdict
 
     def _get_format_specification(self):
-        names = list(StorageFormatManager(self).signature_keyword_names)
+        result = _format._inspect_signature(self)
+        signature_keyword_names = result[1]
+        names = list(signature_keyword_names)
         if "items" in names:
             names.remove("items")
-        return FormatSpecification(
-            self,
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             storage_format_args_values=[self._collection],
             storage_format_keyword_names=names,
             template_names=names,
@@ -470,12 +468,7 @@ class TypedFrozenset(TypedCollection, collections.abc.Set):
 
         Returns integer.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __le__(self, argument):
         """
@@ -717,11 +710,11 @@ class TypedList(TypedCollection, collections.abc.MutableSequence):
             >>> print(string)
             abjad.TypedList(
                 [
-                    abjad.Dynamic('ppp'),
-                    abjad.Dynamic('p'),
-                    abjad.Dynamic('mp'),
-                    abjad.Dynamic('mf'),
-                    abjad.Dynamic('fff'),
+                    Dynamic(name='ppp', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=-4, tweaks=None),
+                    Dynamic(name='p', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=-2, tweaks=None),
+                    Dynamic(name='mp', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=-1, tweaks=None),
+                    Dynamic(name='mf', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=1, tweaks=None),
+                    Dynamic(name='fff', command=None, direction=None, format_hairpin_stop=False, hide=False, leak=False, name_is_textual=False, ordinal=4, tweaks=None),
                     ],
                 item_class=abjad.Dynamic,
                 )
@@ -811,14 +804,14 @@ class TypedList(TypedCollection, collections.abc.MutableSequence):
     ### PRIVATE METHODS ###
 
     def _get_format_specification(self):
-        names = list(StorageFormatManager(self).signature_keyword_names)
+        result = _format._inspect_signature(self)
+        signature_keyword_names = result[1]
+        names = list(signature_keyword_names)
         if "items" in names:
             names.remove("items")
         if "keep_sorted" in names:
             names.remove("keep_sorted")
-        return FormatSpecification(
-            self,
-            repr_is_indented=False,
+        return _format.FormatSpecification(
             storage_format_args_values=[self._collection],
             storage_format_keyword_names=names,
         )
@@ -1070,10 +1063,10 @@ class TypedTuple(TypedCollection, collections.abc.Sequence):
 
         if isinstance(argument, type(self)):
             items = argument._collection
-            return new(self, items=self._collection[:] + items)
+            return _new.new(self, items=self._collection[:] + items)
         elif isinstance(argument, type(self._collection)):
             items = argument[:]
-            return new(self, items=self._collection[:] + items)
+            return _new.new(self, items=self._collection[:] + items)
         raise NotImplementedError
 
     def __contains__(self, item):
@@ -1108,12 +1101,7 @@ class TypedTuple(TypedCollection, collections.abc.Sequence):
 
         Returns integer.
         """
-        hash_values = StorageFormatManager(self).get_hash_values()
-        try:
-            result = hash(hash_values)
-        except TypeError:
-            raise TypeError(f"unhashable type: {self}")
-        return result
+        return hash(self.__class__.__name__ + str(self))
 
     def __mul__(self, argument):
         """
@@ -1122,14 +1110,14 @@ class TypedTuple(TypedCollection, collections.abc.Sequence):
         Returns new typed tuple.
         """
         items = self._collection * argument
-        return new(self, items=items)
+        return _new.new(self, items=items)
 
     def __radd__(self, argument):
         """
         Right-adds ``argument`` to typed tuple.
         """
         items = argument + self._collection
-        return new(self, items=items)
+        return _new.new(self, items=items)
 
     def __rmul__(self, argument):
         """
